@@ -1,45 +1,18 @@
-import datetime
 import logging
 
 from unittest.mock import Mock
 
-import polib
-
 from django.test import TestCase, override_settings
-from freezegun import freeze_time
 from requests.exceptions import RequestException
-from wagtail.core.models import Locale, Page
+from wagtail.core.models import Locale
 
 import wagtail_localize_rws_languagecloud.sync as sync
 
-from wagtail_localize.models import Translation, TranslationSource
-from wagtail_localize.test.models import TestPage
+from wagtail_localize.models import Translation
 
 from ..models import LanguageCloudFile, LanguageCloudProject
 from ..rws_client import ApiClient
-
-
-def create_test_page(**kwargs):
-    parent = kwargs.pop("parent", None) or Page.objects.get(slug="home")
-    page = parent.add_child(instance=TestPage(**kwargs))
-    revision = page.save_revision()
-    revision.publish()
-    source, created = TranslationSource.get_or_create_from_instance(page)
-    return page, source
-
-
-def create_test_po(entries):
-    po = polib.POFile(wrapwidth=200)
-    po.metadata = {
-        "POT-Creation-Date": str(datetime.datetime.utcnow()),
-        "MIME-Version": "1.0",
-        "Content-Type": "text/html; charset=utf-8",
-    }
-
-    for entry in entries:
-        po.append(polib.POEntry(msgctxt=entry[0], msgid=entry[1], msgstr=entry[2]))
-
-    return po
+from .helpers import create_test_page, create_test_po, create_test_project_settings
 
 
 class TestImport(TestCase):
@@ -108,6 +81,7 @@ class TestImport(TestCase):
         for file_ in self.lc_files:
             file_.refresh_from_db()
             self.assertEqual(file_.internal_status, LanguageCloudFile.STATUS_IMPORTED)
+            self.assertEqual(file_.combined_status, "Translations ready for review")
 
     def test_import_all_get_project_calls_fail(self):
         client = ApiClient()
@@ -125,6 +99,9 @@ class TestImport(TestCase):
         for file_ in self.lc_files:
             file_.refresh_from_db()
             self.assertEqual(file_.internal_status, LanguageCloudFile.STATUS_NEW)
+            self.assertEqual(
+                file_.combined_status, "Translations happening in LanguageCloud"
+            )
 
     def test_import_some_get_project_calls_fail(self):
         client = ApiClient()
@@ -142,21 +119,29 @@ class TestImport(TestCase):
             proj.refresh_from_db()
         for file_ in self.lc_files:
             file_.refresh_from_db()
+
         self.assertEqual(
             self.lc_projects[0].internal_status, LanguageCloudProject.STATUS_NEW
         )
         self.assertEqual(self.lc_files[0].internal_status, LanguageCloudFile.STATUS_NEW)
+        self.assertEqual(
+            self.lc_files[0].combined_status, "Translations happening in LanguageCloud"
+        )
+
         self.assertEqual(
             self.lc_projects[1].internal_status, LanguageCloudProject.STATUS_IMPORTED
         )
         self.assertEqual(
             self.lc_files[1].internal_status, LanguageCloudFile.STATUS_IMPORTED
         )
+        self.assertEqual(
+            self.lc_files[1].combined_status, "Translations ready for review"
+        )
 
     def test_import_no_records_to_process(self):
         self.lc_projects[0].internal_status = LanguageCloudProject.STATUS_IMPORTED
         self.lc_projects[0].save()
-        self.lc_projects[1].internal_status = LanguageCloudProject.STATUS_IMPORTED
+        self.lc_projects[1].lc_project_status = "archived"
         self.lc_projects[1].save()
 
         client = ApiClient()
@@ -195,7 +180,17 @@ class TestImport(TestCase):
             self.lc_projects[1].internal_status, LanguageCloudProject.STATUS_NEW
         )
 
+        for file_ in self.lc_files:
+            file_.refresh_from_db()
+        self.assertEqual(
+            self.lc_files[0].combined_status, "Translations ready for review"
+        )
+        self.assertEqual(
+            self.lc_files[1].combined_status, "Translations happening in LanguageCloud"
+        )
 
+
+@override_settings(WAGTAILLOCALIZE_RWS_LANGUAGECLOUD={"LOCATION_ID": 123})
 class TestExport(TestCase):
     def setUp(self):
         self.locale_en = Locale.objects.get(language_code="en")
@@ -210,18 +205,33 @@ class TestExport(TestCase):
                 test_charfield=f"Some test translatable content {i}",
             )
             self.sources.append(source)
-            self.translations.append(
-                Translation.objects.create(
-                    source=source,
-                    target_locale=self.locale_fr,
-                )
+            fr_translation = Translation.objects.create(
+                source=source,
+                target_locale=self.locale_fr,
             )
-            self.translations.append(
-                Translation.objects.create(
-                    source=source,
-                    target_locale=self.locale_de,
-                )
+            self.translations.append(fr_translation)
+            de_translation = Translation.objects.create(
+                source=source,
+                target_locale=self.locale_de,
             )
+            self.translations.append(de_translation)
+            create_test_project_settings(source, [fr_translation, de_translation])
+
+        self.get_project_templates_mock = Mock(
+            side_effect=[
+                {
+                    "items": [
+                        {
+                            "id": "123456",
+                            "name": "Project X",
+                            "location": {"id": "1337", "name": "Project Folder"},
+                        }
+                    ],
+                    "itemCount": 1,
+                }
+            ],
+            spec=True,
+        )
         self.logger = logging.getLogger(__name__)
         logging.disable()  # supress log output under test
 
@@ -240,7 +250,9 @@ class TestExport(TestCase):
             ],
             spec=True,
         )
+        client.get_project_templates = self.get_project_templates_mock
         sync._export(client, self.logger)
+
         self.assertEqual(client.create_project.call_count, 2)
         self.assertEqual(client.create_source_file.call_count, 4)
         lc_projects = [
@@ -258,8 +270,14 @@ class TestExport(TestCase):
         )
         self.assertEqual(proj1_files[0].lc_source_file_id, "file1")
         self.assertEqual(proj1_files[0].create_attempts, 1)
+        self.assertEqual(
+            proj1_files[0].combined_status, "Translations happening in LanguageCloud"
+        )
         self.assertEqual(proj1_files[1].lc_source_file_id, "file2")
         self.assertEqual(proj1_files[1].create_attempts, 1)
+        self.assertEqual(
+            proj1_files[1].combined_status, "Translations happening in LanguageCloud"
+        )
 
         self.assertEqual(lc_projects[1].lc_project_id, "proj2")
         self.assertEqual(lc_projects[1].create_attempts, 1)
@@ -268,8 +286,14 @@ class TestExport(TestCase):
         )
         self.assertEqual(proj2_files[0].lc_source_file_id, "file3")
         self.assertEqual(proj2_files[0].create_attempts, 1)
+        self.assertEqual(
+            proj2_files[0].combined_status, "Translations happening in LanguageCloud"
+        )
         self.assertEqual(proj2_files[1].lc_source_file_id, "file4")
         self.assertEqual(proj2_files[1].create_attempts, 1)
+        self.assertEqual(
+            proj2_files[1].combined_status, "Translations happening in LanguageCloud"
+        )
 
     def test_export_all_create_project_api_calls_fail(self):
         client = ApiClient()
@@ -278,7 +302,9 @@ class TestExport(TestCase):
         client.create_source_file = Mock(
             side_effect=ValueError("this should never be called"), spec=True
         )
+        client.get_project_templates = self.get_project_templates_mock
         sync._export(client, self.logger)
+
         self.assertEqual(client.create_project.call_count, 4)
         self.assertEqual(client.create_source_file.call_count, 0)
 
@@ -293,6 +319,7 @@ class TestExport(TestCase):
         for file_ in lc_files:
             self.assertEqual(file_.lc_source_file_id, "")
             self.assertEqual(file_.create_attempts, 0)
+            self.assertEqual(file_.combined_status, "Request created")
 
     def test_export_some_create_project_api_calls_fail(self):
         client = ApiClient()
@@ -308,6 +335,8 @@ class TestExport(TestCase):
         client.create_source_file = Mock(
             side_effect=[{"id": "file3"}, {"id": "file4"}], spec=True
         )
+        client.get_project_templates = self.get_project_templates_mock
+
         sync._export(client, self.logger)
         self.assertEqual(client.create_project.call_count, 3)
         self.assertEqual(client.create_source_file.call_count, 2)
@@ -326,8 +355,10 @@ class TestExport(TestCase):
         )
         self.assertEqual(proj1_files[0].lc_source_file_id, "")
         self.assertEqual(proj1_files[0].create_attempts, 0)
+        self.assertEqual(proj1_files[0].combined_status, "Request created")
         self.assertEqual(proj1_files[1].lc_source_file_id, "")
         self.assertEqual(proj1_files[1].create_attempts, 0)
+        self.assertEqual(proj1_files[1].combined_status, "Request created")
 
         self.assertEqual(lc_projects[1].lc_project_id, "proj2")
         self.assertEqual(lc_projects[1].create_attempts, 1)
@@ -336,8 +367,14 @@ class TestExport(TestCase):
         )
         self.assertEqual(proj2_files[0].lc_source_file_id, "file3")
         self.assertEqual(proj2_files[0].create_attempts, 1)
+        self.assertEqual(
+            proj2_files[0].combined_status, "Translations happening in LanguageCloud"
+        )
         self.assertEqual(proj2_files[1].lc_source_file_id, "file4")
         self.assertEqual(proj2_files[1].create_attempts, 1)
+        self.assertEqual(
+            proj2_files[1].combined_status, "Translations happening in LanguageCloud"
+        )
 
     def test_export_some_create_file_api_calls_fail(self):
         client = ApiClient()
@@ -354,7 +391,9 @@ class TestExport(TestCase):
             ],
             spec=True,
         )
+        client.get_project_templates = self.get_project_templates_mock
         sync._export(client, self.logger)
+
         self.assertEqual(client.create_project.call_count, 2)
         self.assertEqual(client.create_source_file.call_count, 4)
         lc_projects = [
@@ -372,8 +411,10 @@ class TestExport(TestCase):
         )
         self.assertEqual(proj1_files[0].lc_source_file_id, "")
         self.assertEqual(proj1_files[0].create_attempts, 1)
+        self.assertEqual(proj1_files[0].combined_status, "Request created")
         self.assertEqual(proj1_files[1].lc_source_file_id, "file2")
         self.assertEqual(proj1_files[1].create_attempts, 1)
+        self.assertEqual(proj1_files[1].combined_status, "Request created")
 
         self.assertEqual(lc_projects[1].lc_project_id, "proj2")
         self.assertEqual(lc_projects[1].create_attempts, 1)
@@ -382,8 +423,10 @@ class TestExport(TestCase):
         )
         self.assertEqual(proj2_files[0].lc_source_file_id, "")
         self.assertEqual(proj2_files[0].create_attempts, 1)
+        self.assertEqual(proj2_files[0].combined_status, "Request created")
         self.assertEqual(proj2_files[1].lc_source_file_id, "file3")
         self.assertEqual(proj2_files[1].create_attempts, 1)
+        self.assertEqual(proj2_files[1].combined_status, "Request created")
 
     def test_export_no_records_to_process(self):
         LanguageCloudProject.objects.create(
@@ -398,6 +441,7 @@ class TestExport(TestCase):
         )
         client = ApiClient()
         client.is_authorized = True
+        client.get_project_templates = self.get_project_templates_mock
         client.create_project = Mock(
             side_effect=[{"id": "abc123"}, {"id": "abc456"}], spec=True
         )
@@ -411,6 +455,7 @@ class TestExport(TestCase):
     def test_export_with_an_exception_finished_processing(self):
         client = ApiClient()
         client.is_authorized = True
+        client.get_project_templates = self.get_project_templates_mock
         client.create_project = Mock(
             side_effect=[{"id": "proj1"}, Exception()], spec=True
         )
@@ -431,6 +476,44 @@ class TestExport(TestCase):
         ]
         self.assertEqual(len(lc_projects), 2)
 
+    def test_export_will_create_projects_if_they_have_settings(self):
+        _, source = create_test_page(
+            title="Test page N",
+            slug="test-page-n",
+            test_charfield="Some test translatable content",
+        )
+        Translation.objects.create(
+            source=source,
+            target_locale=self.locale_fr,
+        )
+
+        # create a translation that is not included in any project settings
+        Translation.objects.create(
+            source=self.sources[0],
+            target_locale=Locale.objects.create(language_code="ru"),
+        )
+
+        client = ApiClient()
+        client.is_authorized = True
+        client.create_project = Mock(
+            side_effect=[{"id": "proj1"}, {"id": "proj2"}], spec=True
+        )
+        client.create_source_file = Mock(
+            side_effect=[
+                {"id": "file1"},
+                {"id": "file2"},
+                {"id": "file3"},
+                {"id": "file4"},
+            ],
+            spec=True,
+        )
+        client.get_project_templates = self.get_project_templates_mock
+        sync._export(client, self.logger)
+
+        self.assertEqual(LanguageCloudProject.objects.count(), 2)
+        self.assertEqual(client.create_project.call_count, 2)
+        self.assertEqual(client.create_source_file.call_count, 4)
+
 
 class TestHelpers(TestCase):
     def setUp(self):
@@ -445,72 +528,54 @@ class TestHelpers(TestCase):
             source=source,
             target_locale=self.locale_fr,
         )
+
         self.logger = logging.getLogger(__name__)
         logging.disable()  # supress log output under test
 
-    @freeze_time("2018-02-02 12:00:01")
-    def test_get_project_name_without_custom_prefix(self):
-        self.assertEqual(
-            sync._get_project_name(self.translation.source, self.locale_en),
-            "Test page_2018-02-02",
+    def _create_project_settings(self, lc_project):
+        lc_project.save()
+        settings, _ = create_test_project_settings(
+            translation_source=self.translation.source,
+            translations=[self.translation],
+            lc_project=lc_project,
         )
+        return settings
 
-    @freeze_time("2018-02-02 12:00:01")
-    @override_settings(
-        WAGTAILLOCALIZE_RWS_LANGUAGECLOUD={"PROJECT_PREFIX": "Website_"},
-    )
-    def test_get_project_name_with_custom_prefix(self):
-        self.assertEqual(
-            sync._get_project_name(self.translation.source, self.locale_en),
-            "Website_Test page_2018-02-02",
-        )
-
-    @freeze_time("2018-02-02 12:00:01")
-    def test_get_project_due_date_without_custom_delta(self):
-        self.assertEqual(sync._get_project_due_date(), "2018-02-09T12:00:01.000Z")
-
-    @freeze_time("2018-02-02 12:00:01")
-    @override_settings(
-        WAGTAILLOCALIZE_RWS_LANGUAGECLOUD={"DUE_BY_DELTA": datetime.timedelta(days=14)},
-    )
-    def test_get_project_due_date_with_custom_delta(self):
-        self.assertEqual(sync._get_project_due_date(), "2018-02-16T12:00:01.000Z")
-
+    @override_settings(WAGTAILLOCALIZE_RWS_LANGUAGECLOUD={"LOCATION_ID": 123})
     def test_create_remote_project_success(self):
         lc_project = LanguageCloudProject.objects.create(
             translation_source=self.translation.source,
             source_last_updated_at=self.translation.source.last_updated_at,
         )
+        self._create_project_settings(lc_project)
+
         client = ApiClient()
         client.is_authorized = True
         client.create_project = Mock(return_value={"id": "abc123"}, spec=True)
         id_ = sync._create_remote_project(
-            lc_project,
-            client,
-            "faketitle",
-            "2020-01-01T00:00:01.000Z",
-            "fakedesc",
+            lc_project, {"project_template_id": "project_location_id"}, client
         )
         lc_project.refresh_from_db()
         self.assertEqual(id_, "abc123")
         self.assertEqual(lc_project.lc_project_id, "abc123")
         self.assertEqual(lc_project.create_attempts, 1)
 
+    @override_settings(WAGTAILLOCALIZE_RWS_LANGUAGECLOUD={"LOCATION_ID": 123})
     def test_create_remote_project_fail(self):
         lc_project = LanguageCloudProject.objects.create(
             translation_source=self.translation.source,
             source_last_updated_at=self.translation.source.last_updated_at,
         )
+        self._create_project_settings(lc_project)
+
         client = ApiClient()
         client.is_authorized = True
         client.create_project = Mock(side_effect=RequestException("oh no"), spec=True)
         with self.assertRaises(RequestException):
             sync._create_remote_project(
                 lc_project,
+                {"project_template_id": "project_location_id"},
                 client,
-                "faketitle",
-                "2020-01-01T00:00:01.000Z",
-                "fakedesc",
             )
         lc_project.refresh_from_db()
         self.assertEqual(lc_project.lc_project_id, "")
@@ -569,7 +634,7 @@ class TestHelpers(TestCase):
         self.assertEqual(lc_source_file.lc_source_file_id, "")
         self.assertEqual(lc_source_file.create_attempts, 1)
 
-    def test_should_export_already_imported(self):
+    def test_should_not_export_already_imported(self):
         self.assertFalse(
             sync._should_export(
                 self.logger,
@@ -587,6 +652,7 @@ class TestHelpers(TestCase):
             source_last_updated_at=self.translation.source.last_updated_at,
             lc_project_id="abc123",
         )
+        self._create_project_settings(lc_project)
         LanguageCloudFile.objects.create(
             translation=self.translation,
             project=lc_project,
@@ -600,6 +666,7 @@ class TestHelpers(TestCase):
             source_last_updated_at=self.translation.source.last_updated_at,
             create_attempts=3,
         )
+        self._create_project_settings(lc_project)
         LanguageCloudFile.objects.create(
             translation=self.translation,
             project=lc_project,
@@ -613,6 +680,7 @@ class TestHelpers(TestCase):
             source_last_updated_at=self.translation.source.last_updated_at,
             create_attempts=0,
         )
+        self._create_project_settings(lc_project)
         LanguageCloudFile.objects.create(
             translation=self.translation,
             project=lc_project,
@@ -621,15 +689,12 @@ class TestHelpers(TestCase):
         self.assertFalse(sync._should_export(self.logger, lc_project))
 
     def test_should_export_new_project(self):
-        self.assertTrue(
-            sync._should_export(
-                self.logger,
-                LanguageCloudProject(
-                    translation_source=self.translation.source,
-                    source_last_updated_at=self.translation.source.last_updated_at,
-                ),
-            )
+        lc_project = LanguageCloudProject(
+            translation_source=self.translation.source,
+            source_last_updated_at=self.translation.source.last_updated_at,
         )
+        self._create_project_settings(lc_project)
+        self.assertTrue(sync._should_export(self.logger, lc_project))
 
     def test_should_export_fails_under_threshold(self):
         lc_project = LanguageCloudProject.objects.create(
@@ -637,6 +702,7 @@ class TestHelpers(TestCase):
             source_last_updated_at=self.translation.source.last_updated_at,
             create_attempts=2,
         )
+        self._create_project_settings(lc_project)
         LanguageCloudFile.objects.create(
             translation=self.translation,
             project=lc_project,
